@@ -11,7 +11,7 @@ import re
 
 apiKeys = {
     "cronos": [],
-    "opt":[
+    "opt": [
         "M88PMFFAS2KAAT71X6UP491MHWA9VMU6V6",
         "NW3G4BUUVFD1D1YRFQSYGDWFZ81KY9K758",
         "2CEAVWSQMGTSTA4A6QS95NHYBPU6SDWMMK"
@@ -175,6 +175,11 @@ apiKeys = {
     "boba": ["8KNECUPEU3FW673BA65P5MD13WRHHWVWTX", "UMBCJRG9TNMB4UUPF4CC679AAPZYRXRRH6",
              "UYDGY2WRN29IG27YSVJ5NNQ3792VZQAH2A"],
     "boba-testnet": ["", "", ""],
+    "gnosis": [
+        "RUBJM9NNIX5HK1H7IPBZ9HJQUVDIZPF9H2",
+        "7QQXJ18WJ6RU3EY8C2YXUP6Z3NMPWVQHB2",
+        "S9VEA15ASFT95YJ1H69WH34VCNEFEVQAX4"
+    ]
 }
 
 defaultFolder = "contract"
@@ -203,7 +208,8 @@ reqUrl = {
     "moonbeam": "https://api-moonbeam.moonscan.io/api?module=contract&action=getsourcecode&address=",
     "moonbase": "https://api-moonbase.moonscan.io/api?module=contract&action=getsourcecode&address=",
     "boba": "https://api.bobascan.com/api?module=contract&action=getsourcecode&address=",
-    "boba-testnet": "https://api-testnet.bobascan.com/api?module=contract&action=getsourcecode&address="
+    "boba-testnet": "https://api-testnet.bobascan.com/api?module=contract&action=getsourcecode&address=",
+    "gnosis": "https://api.gnosisscan.io/api?module=contract&action=getsourcecode&address="
 
 }
 
@@ -272,9 +278,10 @@ contractInfo = {}
 
 proxyContract = {}
 
+
 def _argparse():
     parser = argparse.ArgumentParser(
-        description="To get contract source code. \n\nSupport network: \nHeco|ETH|BSC|Fantom|Poly|AVAX|ARBI|Tron\nCronos|moonbeam|moonriver|boba|okex|opt\navax-testnet|arbi-testnet|poly-testnet\nbsc-testnet|heco-testnet|ftm-testnet\nGoerli|Kovan|Rinkeby|Ropsten\nmoonbase|boba-testnet\n\nGet code by tx only supports:\nBSC|ETH|BOBA|ARBI|HECO",
+        description="To get contract source code. \n\nSupport network: \nHeco|ETH|BSC|Fantom|Poly|AVAX|ARBI|Tron\nCronos|moonbeam|moonriver|boba|okex|opt\navax-testnet|arbi-testnet|poly-testnet\nbsc-testnet|heco-testnet|ftm-testnet\nGoerli|Kovan|Rinkeby|Ropsten\nmoonbase|boba-testnet|gnosis\n\nGet code by tx only supports:\nBSC|ETH|BOBA|ARBI|HECO",
         formatter_class=RawTextHelpFormatter)
     parser.add_argument('-i', default='', dest='inputFile', help='Input file path including contract addresses.')
     parser.add_argument('-o', default='', dest='outputFolder', help='Choose a folder to export.')
@@ -368,7 +375,7 @@ def getCode(inputFile, outputFolder, address, network):
                 print("Erorr input")
                 os._exit(0)
             if addresses != []:
-                sendRequest(addresses, outputFolder, network,"")
+                sendRequest(addresses, outputFolder, network, "")
             else:
                 print("Erorr address")
                 os._exit(0)
@@ -419,7 +426,7 @@ def getAddresses(inputFile, isTron, addString):
         os._exit(0)
 
 
-def exportResult(result, outputFolder, network, address,typeOf):
+def exportResult(result, outputFolder, network, address, typeOf):
     global contractIndex
     if "ContractName" not in result.keys():
         return
@@ -466,18 +473,18 @@ def exportResult(result, outputFolder, network, address,typeOf):
         if network == "cronos":
             if result["IsProxy"] == True:
                 if typeOf == "bytx":
-                    proxyContract[address]=result['ImplementationAddress']
+                    proxyContract[address] = result['ImplementationAddress']
                     return
                 addresses = []
                 addresses.append(result['ImplementationAddress'])
-                sendRequest(addresses, "ImplementationAddress", network,"")
+                sendRequest(addresses, "ImplementationAddress", network, "")
         elif result['Implementation'] != "":
             if typeOf == "bytx":
                 proxyContract[address] = result['Implementation']
                 return
             addresses = []
             addresses.append(result['Implementation'])
-            sendRequest(addresses, "Implementation", network,"")
+            sendRequest(addresses, "Implementation", network, "")
     except Exception as e:
         print("--------------------------------------")
         print("error line:", e.__traceback__.tb_lineno)
@@ -497,7 +504,7 @@ def mkdir(path):
         return False
 
 
-def sendRequest(addresses, outputFolder, network,typeOf):
+def sendRequest(addresses, outputFolder, network, typeOf):
     try:
         proxies = {
             "https": "http://" + proxy,
@@ -519,7 +526,7 @@ def sendRequest(addresses, outputFolder, network,typeOf):
                 outputData = results
             elif type(results) == list:
                 outputData = results[0]
-            exportResult(outputData, outputFolder, network, address,typeOf)
+            exportResult(outputData, outputFolder, network, address, typeOf)
     except Exception as e:
         print("--------------------------------------")
         print("error line:", e.__traceback__.tb_lineno)
@@ -675,11 +682,11 @@ def main():
         else:
             print("Invalid command")
             os._exit(0)
-        if contractInfo!={}:
+        if contractInfo != {}:
             print("\nAddress => ContractName:")
             for key in contractInfo.keys():
                 print(f"{key}\t{contractInfo[key]}")
-        if proxyContract!={}:
+        if proxyContract != {}:
             print("\nProxy => Implementation:")
             for key in proxyContract.keys():
                 print(f"{key}\t{proxyContract[key]}")
